define(
//begin v1.x content
{
	"HKD_displayName": "dolar hongkoński",
	"CHF_displayName": "frank szwajcarski",
	"CHF_symbol": "CHF",
	"JPY_symbol": "JPY",
	"CAD_displayName": "dolar kanadyjski",
	"HKD_symbol": "HKD",
	"CNY_displayName": "juan chiński",
	"USD_symbol": "USD",
	"AUD_displayName": "dolar australijski",
	"JPY_displayName": "jen japoński",
	"CAD_symbol": "CAD",
	"USD_displayName": "dolar amerykański",
	"CNY_symbol": "CNY",
	"GBP_displayName": "funt szterling",
	"GBP_symbol": "GBP",
	"AUD_symbol": "AUD",
	"EUR_displayName": "euro"
}
//end v1.x content
);